from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import File, Boolean, Int, String, Float

Xxmotif_V0_1_0 = CommandToolBuilder(tool="XXmotif", base_command=["XXmotif"], inputs=[ToolInput(tag="in_neg_set", input_type=File(optional=True), prefix="--negSet", doc=InputDocumentation(doc="sequence set which has to be used as a reference set")), ToolInput(tag="in_z_oops", input_type=Boolean(optional=True), prefix="--zoops", doc=InputDocumentation(doc="use zero-or-one occurrence per sequence model (DEFAULT)")), ToolInput(tag="in_mops", input_type=Boolean(optional=True), prefix="--mops", doc=InputDocumentation(doc="use multiple occurrence per sequence model")), ToolInput(tag="in_oops", input_type=Boolean(optional=True), prefix="--oops", doc=InputDocumentation(doc="use one occurrence per sequence model")), ToolInput(tag="in_rev_comp", input_type=Boolean(optional=True), prefix="--revcomp", doc=InputDocumentation(doc="search in reverse complement of sequences as well (DEFAULT: NO)")), ToolInput(tag="in_background_model_order", input_type=Int(optional=True), prefix="--background-model-order", doc=InputDocumentation(doc="order of background distribution (DEFAULT: 2, 8(--negset) )")), ToolInput(tag="in_pseudo", input_type=Int(optional=True), prefix="--pseudo", doc=InputDocumentation(doc="percentage of pseudocounts used (DEFAULT: 10)")), ToolInput(tag="in_gaps", input_type=Int(optional=True), prefix="--gaps", doc=InputDocumentation(doc="maximum number of gaps used for start seeds [0-3] (DEFAULT: 0)")), ToolInput(tag="in_type", input_type=String(optional=True), prefix="--type", doc=InputDocumentation(doc="defines what kind of start seeds are used (DEFAULT: ALL)\n- possible types: ALL, FIVEMERS, PALINDROME, TANDEM, NOPALINDROME, NOTANDEM")), ToolInput(tag="in_merge_motif_threshold", input_type=String(optional=True), prefix="--merge-motif-threshold", doc=InputDocumentation(doc="defines the similarity threshold for merging motifs (DEFAULT: HIGH)\n- possible modes: LOW, MEDIUM, HIGH")), ToolInput(tag="in_no_pwm_length_optimization", input_type=Boolean(optional=True), prefix="--no-pwm-length-optimization", doc=InputDocumentation(doc="do not optimize length during iterations (runtime advantages)")), ToolInput(tag="in_max_match_positions", input_type=Int(optional=True), prefix="--max-match-positions", doc=InputDocumentation(doc="max number of positions per motif (DEFAULT: 17, higher values will lead to very long runtimes)")), ToolInput(tag="in_batch", input_type=Boolean(optional=True), prefix="--batch", doc=InputDocumentation(doc="suppress progress bars (reduce output size for batch jobs)")), ToolInput(tag="in_max_pos_setsize", input_type=Int(optional=True), prefix="--maxPosSetSize", doc=InputDocumentation(doc="maximum number of sequences from the positive set used [DEFAULT: all]")), ToolInput(tag="in_tracked_motif", input_type=String(optional=True), prefix="--trackedMotif", doc=InputDocumentation(doc="inspect extensions and refinement of a given seed (DEFAULT: not used)")), ToolInput(tag="in_format", input_type=String(optional=True), prefix="--format", doc=InputDocumentation(doc="|MFASTA                   defines what kind of format the input sequences have (DEFAULT: FASTA)")), ToolInput(tag="in_max_multiple_sequences", input_type=Int(optional=True), prefix="--maxMultipleSequences", doc=InputDocumentation(doc="maximum number of sequences used in an alignment [DEFAULT: all]")), ToolInput(tag="in_localization", input_type=Boolean(optional=True), prefix="--localization", doc=InputDocumentation(doc="use localization information to calculate combined P-values\n(sequences should have all the same length)")), ToolInput(tag="in_downstream", input_type=Int(optional=True), prefix="--downstream", doc=InputDocumentation(doc="number of residues in positive set downstream of anchor point (DEFAULT: 0)")), ToolInput(tag="in_start_motif", input_type=String(optional=True), prefix="--startMotif", doc=InputDocumentation(doc="Start motif (IUPAC characters)")), ToolInput(tag="in_profile_file", input_type=File(optional=True), prefix="--profileFile", doc=InputDocumentation(doc="profile file")), ToolInput(tag="in_start_region", input_type=Int(optional=True), prefix="--startRegion", doc=InputDocumentation(doc="expected start position for motif occurrences relative to anchor point (--localization)")), ToolInput(tag="in_endregion", input_type=Int(optional=True), prefix="--endRegion", doc=InputDocumentation(doc="expected end position for motif occurrences relative to anchor point (--localization)")), ToolInput(tag="in_em", input_type=Boolean(optional=True), prefix="--em", doc=InputDocumentation(doc="EM mode.")), ToolInput(tag="in_binding_site_file", input_type=File(optional=True), prefix="--bindingSiteFile", doc=InputDocumentation(doc="Binding sites file name to initialize a single Markov model. Sequence lengths must not differ and be provided line-by-line.")), ToolInput(tag="in_binding_site_length", input_type=Int(optional=True), prefix="--bindingSiteLength", doc=InputDocumentation(doc="Specify the length of binding sites provided by --bindingSiteFile (not mandatory).")), ToolInput(tag="in_markov_model_file", input_type=File(optional=True), prefix="--markovModelFile", doc=InputDocumentation(doc="Markov model file name (without ending) to initialize a single Markov model. Files <FILE>.conds and <FILE>.probs need to be available.")), ToolInput(tag="in_nr_models", input_type=Int(optional=True), prefix="--nrModels", doc=InputDocumentation(doc="[<INTEGER>...]\nNumber of one or more XXmotif models in the ranking used to initialize Markov models. The remaining parameters available to choose models from XXmotif results are ignored.")), ToolInput(tag="in_min_models", input_type=Int(optional=True), prefix="--minModels", doc=InputDocumentation(doc="Min. number of XXmotif models used to initialize Markov models. Independent on options --maxPvalue and --minOccurrence. <INTEGER> > 0 (default: 1).")), ToolInput(tag="in_max_models", input_type=Int(optional=True), prefix="--maxModels", doc=InputDocumentation(doc="Max. number of XXmotif models used to initialize Markov models. <INTEGER> > 0 (default: max. integer).")), ToolInput(tag="in_maxp_value", input_type=Float(optional=True), prefix="--maxPvalue", doc=InputDocumentation(doc="Max. p-value of XXmotif models used to initialize Markov models. Not applied to min. number of models. (default: 1).")), ToolInput(tag="in_min_occurrence", input_type=Float(optional=True), prefix="--minOccurrence", doc=InputDocumentation(doc="Min. percentage of sequences containing a binding site instance. Not applied to min. number of models. (default: 0).")), ToolInput(tag="in_add_columns", input_type=Int(optional=True), prefix="--addColumns", doc=InputDocumentation(doc="{1,2}\nAdd columns to the left and/or right of models. <INTEGER> >= 0 (default: 0 0).")), ToolInput(tag="in_markov_model_order", input_type=Int(optional=True), prefix="-k", doc=InputDocumentation(doc="Markov model order. <INTEGER> >= 0 (default: 0).")), ToolInput(tag="in_markov_model_pseudocounts_factors_order", input_type=Float(optional=True), prefix="--alpha", doc=InputDocumentation(doc="[<FLOAT>...]\nMarkov model pseudo-counts factor(s). Markov model order k fixes vector size to k+1. <FLOAT> >= 0 (default: 10).")), ToolInput(tag="in_eta", input_type=Float(optional=True), prefix="--eta", doc=InputDocumentation(doc="[<FLOAT>...]\nMarkov model pseudo-counts factor(s) defined by --alpha and -q. Markov model order k fixes vector size to k+1. Specify either --eta or --alpha. <FLOAT> >= 0 (default: 10).")), ToolInput(tag="in_interpolate", input_type=Boolean(optional=True), prefix="--interpolate", doc=InputDocumentation(doc="Interpolate between higher- and lower-order probabilities.")), ToolInput(tag="in_background_model_order", input_type=Int(optional=True), prefix="-K", doc=InputDocumentation(doc="Background model order. <INTEGER> >= 0. (default: 0).")), ToolInput(tag="in_background_model_pseudocounts", input_type=Float(optional=True), prefix="--Alpha", doc=InputDocumentation(doc="Background model pseudo-counts factor. <FLOAT> >= 0 (default: 10).")), ToolInput(tag="in_no_expectation_maximization_phase", input_type=Boolean(optional=True), prefix="--noExpectationMaximizationPhase", doc=InputDocumentation(doc="Initialize Markov model but skip EM phase.")), ToolInput(tag="in_specificity_factor_approximates", input_type=Float(optional=True), prefix="-q", doc=InputDocumentation(doc="Specificity factor approximates the percentage of sequences contributing to the Markov model. 0 < <FLOAT> < 1 (default: 0.1).")), ToolInput(tag="in_epsilon", input_type=Float(optional=True), prefix="--epsilon", doc=InputDocumentation(doc="EM convergence parameter. <FLOAT> > 0 (default: 0.001).")), ToolInput(tag="in_max_em_iterations", input_type=Int(optional=True), prefix="--maxEMIterations", doc=InputDocumentation(doc="Max. number of EM iterations (default: max. integer).")), ToolInput(tag="in_sequence_ints_file", input_type=File(optional=True), prefix="--sequenceIntsFile", doc=InputDocumentation(doc="Intensity or significance values for positive sequences. The higher the values the higher the weights.")), ToolInput(tag="in_in_it_ints", input_type=Boolean(optional=True), prefix="--initInts", doc=InputDocumentation(doc="Parameter to initialize models from XXmotif results by weighting instances with corresponding sequence weigths. Option --sequenceIntsFile must be provided simultaneously. Options --bindingSiteFile and --markovModelFile must not be provided simultaneously.")), ToolInput(tag="in_rank_weighting", input_type=Boolean(optional=True), prefix="--rankWeighting", doc=InputDocumentation(doc="Rank-based weighting (default: intensity-based weighting).")), ToolInput(tag="in_background_quantile", input_type=Float(optional=True), prefix="--backgroundQuantile", doc=InputDocumentation(doc="Quantile to estimate the background intensity value (or rank). Sequences having their intensity value (rank) below (above) the background intensity value (rank) get assigned to weight zero. 0 <= <FLOAT> <= 1 (default: 0).")), ToolInput(tag="in_background_intensity", input_type=Float(optional=True), prefix="--backgroundIntensity", doc=InputDocumentation(doc="Background intensity value. Sequences having their intensity value below the background intensity value get assigned to weight zero. Option --rankWeighting must not be provided simultaneously (default: min. intensity value).")), ToolInput(tag="in_background_rank", input_type=Int(optional=True), prefix="--backgroundRank", doc=InputDocumentation(doc="Background intensity rank. Sequences having their intensity rank above the background intensity rank get assigned to weight zero. Option --rankWeighting must be provided simultaneously (default: max. rank).")), ToolInput(tag="in_binding_site_ints_file", input_type=File(optional=True), prefix="--bindingSiteIntsFile", doc=InputDocumentation(doc="Intensity or significance values for binding site sequences. The higher the values the higher the weights. Option --bindingSiteFile must be provided simultaneously.")), ToolInput(tag="in_binding_site_rank_weighting", input_type=Boolean(optional=True), prefix="--bindingSiteRankWeighting", doc=InputDocumentation(doc="Binding site rank-based weighting (default: intensity-based weighting).")), ToolInput(tag="in_binding_site_background_quantile", input_type=Float(optional=True), prefix="--bindingSiteBackgroundQuantile", doc=InputDocumentation(doc="Quantile to estimate the background intensity value (or rank). Binding sites having their intensity value (rank) below (below) the background intensity value (rank) get assigned to weight zero. 0 <= <FLOAT> <= 1 (default: 0).")), ToolInput(tag="in_binding_site_background_intensity", input_type=Float(optional=True), prefix="--bindingSiteBackgroundIntensity", doc=InputDocumentation(doc="Background intensity value. Binding sites having their intensity value below the background intensity value get assigned to weight zero. Option --bindingSiteRankWeighting must not be provided simultaneously (default: min. intensity value).")), ToolInput(tag="in_binding_site_background_rank", input_type=Int(optional=True), prefix="--bindingSiteBackgroundRank", doc=InputDocumentation(doc="Background intensity rank. Binding sites having their intensity rank above the background intensity rank get assigned to weight zero. Option --bindingSiteRankWeighting must be provided simultaneously (default: max. rank).")), ToolInput(tag="in_test_pos_set", input_type=Boolean(optional=True), prefix="--testPosSet", doc=InputDocumentation(doc="Evaluate model(s) on training sequences.")), ToolInput(tag="in_test_neg_set", input_type=Boolean(optional=True), prefix="--testNegSet", doc=InputDocumentation(doc="Evaluate model(s) on background sequences.")), ToolInput(tag="in_test_set", input_type=File(optional=True), prefix="--testSet", doc=InputDocumentation(doc="Evaluate model(s) on sequences in FASTA format. Specify one or more files. Sequence lengths may differ.")), ToolInput(tag="in_evaluate_pwm_s", input_type=Boolean(optional=True), prefix="--evaluatePWMs", doc=InputDocumentation(doc="Evaluate PWM model(s) used to initialize Markov model(s) on test sequences.")), ToolInput(tag="in_log_probs", input_type=Boolean(optional=True), prefix="--logProbs", doc=InputDocumentation(doc="Calculate log probabilities instead of log likelihood ratios.")), ToolInput(tag="in_save_init_models", input_type=Boolean(optional=True), prefix="--saveInitModels", doc=InputDocumentation(doc="Save Markov models after initialization to file.")), ToolInput(tag="in_save_models", input_type=Boolean(optional=True), prefix="--saveModels", doc=InputDocumentation(doc="Save Markov models after EM phase to file.")), ToolInput(tag="in_save_expectation_maximization_likelihoods", input_type=Boolean(optional=True), prefix="--saveExpectationMaximizationLikelihoods", doc=InputDocumentation(doc="Save EM iteration's sequence likelihoods and positional odds to file.")), ToolInput(tag="in_save_expectation_maximization_models", input_type=Boolean(optional=True), prefix="--saveExpectationMaximizationModels", doc=InputDocumentation(doc="Save EM iteration's Markov models to file.")), ToolInput(tag="in_verbose", input_type=Boolean(optional=True), prefix="--verbose", doc=InputDocumentation(doc="Verbose printouts.\n")), ToolInput(tag="in_outdir", input_type=String(), position=0, doc=InputDocumentation(doc="")), ToolInput(tag="in_seq_file", input_type=String(), position=1, doc=InputDocumentation(doc=""))], outputs=[], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Xxmotif_V0_1_0().translate("wdl", allow_empty_container=True)

